﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

using System.Drawing.Printing;
using System.Drawing.Drawing2D;

namespace howto_printer_resolution
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        // List the available printers.
        private void Form1_Load(object sender, EventArgs e)
        {
            foreach (string printer in PrinterSettings.InstalledPrinters)
                cboPrinter.Items.Add(printer);
        }

        // Print.
        private void btnPrint_Click(object sender, EventArgs e)
        {
            // Select the printer.
            pdocSmiley.PrinterSettings.PrinterName = cboPrinter.Text;

            // Pick the selected resolution.
            pdocSmiley.DefaultPageSettings.PrinterResolution =
                pdocSmiley.DefaultPageSettings.PrinterSettings.
                    PrinterResolutions[cboResolution.SelectedIndex];

            // Print.
            pdocSmiley.Print();
        }

        // Draw the smiley face.
        private void pdocSmiley_PrintPage(object sender, System.Drawing.Printing.PrintPageEventArgs e)
        {
            e.Graphics.SmoothingMode = SmoothingMode.AntiAlias;

            e.Graphics.TranslateTransform(1, 1);
            e.Graphics.ScaleTransform(100, 100,
                System.Drawing.Drawing2D.MatrixOrder.Append);
            e.Graphics.TranslateTransform(
                e.MarginBounds.X,
                e.MarginBounds.Y,
                System.Drawing.Drawing2D.MatrixOrder.Append);
            DrawSmiley(e.Graphics);
        }

        // Draw a smiley face in the area (-1, -1)-(1, 1).
        private void DrawSmiley(Graphics gr)
        {
            using (Pen thin_pen = new Pen(Color.Black, 0))
            {
                gr.FillEllipse(Brushes.Yellow, -1, -1, 2, 2);
                gr.DrawEllipse(thin_pen, -1, -1, 2, 2);

                gr.FillEllipse(Brushes.LightGreen, -0.5F, -0.5F, 0.3F, 0.5F);
                gr.DrawEllipse(thin_pen, -0.5F, -0.5F, 0.3F, 0.5F);
                gr.FillEllipse(Brushes.Black, -0.4F, -0.4F, 0.2F, 0.3F);

                gr.FillEllipse(Brushes.LightGreen, 0.2F, -0.5F, 0.3F, 0.5F);
                gr.DrawEllipse(thin_pen, 0.2F, -0.5F, 0.3F, 0.5F);
                gr.FillEllipse(Brushes.Black, 0.3F, -0.4F, 0.2F, 0.3F);

                gr.FillEllipse(Brushes.LightBlue, -0.2F, -0.1F, 0.4F, 0.6F);
                gr.DrawEllipse(thin_pen, -0.2F, -0.1F, 0.4F, 0.6F);

                gr.DrawArc(thin_pen, -0.75F, -0.75F, 1.5F, 1.5F, 20, 120);
            }
        }

        // Display this printer's available resolutions.
        private void cboPrinter_SelectedIndexChanged(object sender, EventArgs e)
        {
            // Select the printer.
            pdocSmiley.PrinterSettings.PrinterName = cboPrinter.Text;

            // Display the available resolutions.
            cboResolution.Items.Clear();
            foreach (PrinterResolution resolution in
                pdocSmiley.DefaultPageSettings.PrinterSettings.PrinterResolutions)
            {
                cboResolution.Items.Add(resolution.ToString());
            }

            // Enable the Print button if a printer and resolution are selected.
            btnPrint.Enabled = (
                (cboPrinter.SelectedIndex > -1) &&
                (cboResolution.SelectedIndex > -1));
        }

        // Enable the Print button if a printer and resolution are selected.
        private void cboResolution_SelectedIndexChanged(object sender, EventArgs e)
        {
            btnPrint.Enabled = (
                (cboPrinter.SelectedIndex > -1) &&
                (cboResolution.SelectedIndex > -1));
        }
    }
}
